// validation.js
const validateName = (value) => /^[a-zA-Z\s]+$/.test(value);
const validatePhone = value => /^[0-9]{8,15}$/.test(value);
const isValidEmail = (email) => {
  var emailRegex = /^[\w-]+(\.[\w-]+)*@([\w-]+\.)+[a-zA-Z]{2,7}$/;
  return emailRegex.test(email);
}
function validateLagoonArea() {
  const lagoonArea = parseFloat($('#lagoonArea').val());
  const landArea = parseFloat($('#landArea').val());
  if (lagoonArea > landArea) {
    $('#lagoonError').html('Lagoon area cannot be greater than land area.').addClass('d-block').removeClass('d-none');
    return false;
  } else {
    $('#lagoonError').removeClass('d-block').addClass('d-none');
    return true;
  }
}

function validateForm() {
  var isValid = true;

  // Reset error messages
  $('.error').addClass('d-none');

  // Validate name
  var name = $('#uname').val().trim();
  if (name === '') {
      $('#nameError').text('Please enter your name').removeClass('d-none');
      isValid = false;
  } else if (!validateName(name)) {
      $('#nameError').text('Please enter a valid name').removeClass('d-none');
      isValid = false;
  }

  // Validate email
  var email = $('#emailId').val().trim();
  if (email === '') {
      $('#emailError').text('Please enter your email').removeClass('d-none');
      isValid = false;
  } else if (!isValidEmail(email)) {
      $('#emailError').text('Please enter a valid email').removeClass('d-none');
      isValid = false;
  }

  // Validate contact number
  var contact = $('#contactNo').val().trim();
  if (contact === '') {
      $('#contactError').text('Please enter your contact number').removeClass('d-none');
      isValid = false;
  } else if (!validatePhone(contact)) {
      $('#contactError').text('Please enter a valid contact number').removeClass('d-none');
      isValid = false;
  }

  // Validate property type and land area
  var propertyType = $('input[name="property_type"]:checked').val();
  var landArea = parseFloat($('#landArea').val());

  var errorMessage = '';

  if (propertyType === 'villa' && landArea < 30) {
      errorMessage = "Land area for villa cannot be less than 30 acres.";
  } else if (propertyType === 'apartment' && landArea < 15) {
      errorMessage = "Land area for apartment cannot be less than 15 acres.";
  } else if (propertyType === 'plot' && landArea < 60) {
      errorMessage = "Land area for plots cannot be less than 60 acres.";
  }

  if (errorMessage !== '') {
      $('#landError').text(errorMessage).removeClass('d-none');
      isValid = false;
  }

// validate lagoon area
  if (!validateLagoonArea()) {
    isValid = false;
}

  return isValid;
}



$(document).ready(function() {
    // Validate form on submit
    $('form[name="roiForm"]').submit(function(event) {
        if (!validateForm()) {
            event.preventDefault();
        }
    });

    // Validate form on input change
    $('input[name="property_type"], #uname, #emailId, #contactNo, #landArea, #lagoonArea').on('input', function() {
        validateForm();
    });
});
